@@ -123,6 +123,8 @@ while true; do
         ;;
         --nv)
             shift
+            SINGULARITY_NV=1
+            export SINGULARITY_NV
             SINGULARITY_NVLIBLIST=`mktemp ${TMPDIR:-/tmp}/.singularity-nvliblist.XXXXXXXX`
             cat $SINGULARITY_sysconfdir"/singularity/nvliblist.conf" | grep -Ev "^#|^\s*$" > $SINGULARITY_NVLIBLIST
             for i in $(ldconfig -p | grep -f "${SINGULARITY_NVLIBLIST}"); do
@@ -141,7 +143,7 @@ while true; do
             else
                 export SINGULARITY_CONTAINLIBS
             fi
-            if NVIDIA_SMI=$(which nvidia-smi); then
+            if NVIDIA_SMI=$(which nvidia-smi 2>/dev/null); then
                 if [ -n "${SINGULARITY_BINDPATH:-}" ]; then
                     SINGULARITY_BINDPATH="${SINGULARITY_BINDPATH},${NVIDIA_SMI}"
                 else
