@@ -1,5 +1,6 @@
 #!/bin/bash
 # 
+# Copyright (c) 2017-2018, SyLabs, Inc. All rights reserved.
 # Copyright (c) 2017, SingularityWare, LLC. All rights reserved.
 # Copyright (c) 2015-2017, Gregory M. Kurtzer. All rights reserved.
 
@@ -24,35 +25,10 @@ if ! mkdir -p "$CONTAINER_DIR"; then
     ABORT 255
 fi
 
-
-case "$SINGULARITY_IMAGE" in
-
-    *.tar)
-
-        message 1 "Opening tar archive, stand by...\n"
-        # this almost always gives permission errors, so ignore them when
-        # running as a user.
-        tar -C "$CONTAINER_DIR" -xf "$SINGULARITY_IMAGE" 2>/dev/null
-
-    ;;
-    *.tgz|*.tar.gz)
-
-        message 1 "Opening gzip compressed archive, stand by...\n"
-
-        # this almost always gives permission errors, so ignore them when
-        # running as a user.
-        tar -C "$CONTAINER_DIR" -xzf "$SINGULARITY_IMAGE" 2>/dev/null
-
-    ;;
-    *.tbz|*.tar.bz)
-
-        message 1 "Opening bzip compressed archive, stand by...\n"
-        # this almost always gives permission errors, so ignore them when
-        # running as a user.
-        tar -C "$CONTAINER_DIR" -xjf "$SINGULARITY_IMAGE" 2>/dev/null
-
-    ;;
-esac
+message 1 "Opening tar archive, stand by...\n"
+# this almost always gives permission errors, so ignore them when
+# running as a user.
+tar -C "$CONTAINER_DIR" -xf "$SINGULARITY_IMAGE" 2>/dev/null
 
 chmod -R +w "$CONTAINER_DIR"
 
