@@ -51,5 +51,8 @@
 
     // Returns the GID of the singularity user.
     gid_t singularity_priv_singularity_gid();
+    
+    // Aborts if host kernel doesn't support NO_NEW_PRIVS
+    void singularity_priv_check_nonewprivs();
 
 #endif /* __PRIVILEGE_H_ */
